using System;
using System.IO;
using System.Text.RegularExpressions;
using System.Web;

namespace HtmlScrubber
{
	public class CoralCDNFilter : TransformRequestFilterBase
	{
		public CoralCDNFilter(Stream original) : base(original)
		{
		}

		protected override ContentTransformation[] GetTransformations()
		{
			string extensionsRegex;

			string host = (string) HttpContext.Current.Items["HTTP_HOST"];
			Regex hostRegex = new Regex(@"(?<domain>[^:]*)(:(?<port>\d+))?");
			hostRegex.Match(host);

			Match match = hostRegex.Match(host);
			if(!match.Success)
			{
				return new ContentTransformation[] { ContentTransformation.Empty };
			}

			string domain = match.Groups["domain"].Value;
			string port = match.Groups["port"].Value;
			string domainRegex = Regex.Escape(domain);
			
			if (CoralCDNConfigSection.GetSettings() != null && !String.IsNullOrEmpty(CoralCDNConfigSection.GetSettings().Extensions))
			{
				string[] extensions = CoralCDNConfigSection.GetSettings()
						.Extensions
						.Split(new string[] { ", ", ",", "|", " " }
							, StringSplitOptions.RemoveEmptyEntries);
				extensionsRegex = String.Join("|", extensions);
			}
			else
				extensionsRegex = "png|css|gif|jpg|jpeg|mpg|mpeg|avi|js|zip";

			return new ContentTransformation[]
			{
				new ContentTransformation(
					string.Format(
						@"(?<pre>(src|href)\s*=\s*""https?://)(?<domain>(.*?\.)?{0})(?<port>:{1})?(?<post>/.*?\.({2})"")"
							, domainRegex
							, port
							, extensionsRegex)
				, "${pre}${domain}.nyud.net${port}${post}")		
			};
		}
	}
}
