using System;
using System.Web;

namespace HtmlScrubber
{
	public abstract class HtmlScrubberModuleBase : IHttpModule
	{
		///<summary>
		///Initializes a module and prepares it to handle requests.
		///</summary>
		///<param name="context">An <see cref="T:System.Web.HttpApplication"></see> that provides access to the methods, properties, and events common to all application objects within an ASP.NET application </param>
		public void Init(HttpApplication context)
		{
			context.BeginRequest += HandleIncoming;
			context.ReleaseRequestState += HandleOutgoing;
		}

		protected abstract void HandleIncoming(object sender, EventArgs e);
		protected abstract void HandleOutgoing(object sender, EventArgs e);

		///<summary>
		///Disposes of the resources (other than memory) used by the module that implements <see cref="T:System.Web.IHttpModule"></see>.
		///</summary>
		///
		public void Dispose()
		{
		}

		internal static bool IsMetaweblogAPIPost()
		{
			return HttpContext.Current.Request.HttpMethod == "POST"
				&& HttpContext.Current.Request.ContentType == "text/xml"
				&& (HttpContext.Current.Request.UserAgent.Contains("Windows Live Writer") 
					|| HttpContext.Current.Request.UserAgent.Contains("BlogJet"));
		}
	}
}
